@@ -2,7 +2,7 @@
 /*
     Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2005  Alexandru Csete.
+    Copyright (C)  2001-2006  Alexandru Csete.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -23,11 +23,11 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the
-          Free Software Foundation, Inc.,
-	  59 Temple Place, Suite 330,
-	  Boston, MA  02111-1307
-	  USA
+    along with this program; if not, visit http://www.fsf.org/
+ 
+ 
+ 
+ 
 */
 /** \file    main.c
  *  \ingroup main
@@ -53,6 +53,8 @@
 #endif
 #include "grig-config.h"
 #include "rig-gui.h"
+#include "grig-debug.h"
+#include "rig-gui-message-window.h"
 #include "rig-daemon.h"
 #include "rig-data.h"
 
@@ -75,12 +77,15 @@ static gboolean listrigs  = FALSE;   /*!< List supported radios and exit. */
 gint     debug     = RIG_DEBUG_NONE; /*!< Hamlib debug level. Note: not static since menubar.c needs access. */
 static gint     delay     = 0;       /*!< Command delay. */
 static gboolean nothread  = FALSE;   /*!< Don't use threads, just a regular gtk-timeout. */
+static gboolean pstat     = FALSE;   /*!< Enable power status button. */
+static gboolean ptt       = FALSE;   /*!< Enable PTT button. */
 static gboolean version   = FALSE;   /*!< Show version and exit. */
 static gboolean help      = FALSE;   /*!< Show help and exit. */
 
 
+/* group those which take no arg */
 /** \brief Short options. */
-#define SHORT_OPTIONS "m:r:s:c:C:d:D:nlhv"  /* group those which take no arg */
+#define SHORT_OPTIONS "m:r:s:c:C:d:D:nlpPhv"  
 
 /** \brief Table of command line options. */
 static struct option long_options[] =
@@ -94,6 +99,8 @@ static struct option long_options[] =
 	{"delay",        1, 0, 'D'},
 	{"nothread",     0, 0, 'n'},
 	{"list",         0, 0, 'l'},
+        {"enable-ptt",   0, 0, 'p'},
+	{"enable-pwr",   0, 0, 'P'},
 	{"help",         0, 0, 'h'},
 	{"version",      0, 0, 'v'},
 	{NULL, 0, 0, 0}
@@ -275,6 +282,16 @@ main (int argc, char *argv[])
 			nothread = TRUE;
 			break;
 
+			/* enable PTT button */
+		case 'p':
+			ptt = TRUE;
+			break;
+
+			/* enable POWER button */
+		case 'P':
+			pstat = TRUE;
+			break;
+
 			/* show help */
 		case 'h':
 			help = TRUE;
@@ -315,10 +332,25 @@ main (int argc, char *argv[])
 	/* we set hamlib debug level to TRACE while we fire up the daemon;
 	   it will be reset when we create the menubar
 	*/
-	rig_set_debug (RIG_DEBUG_TRACE);
+	grig_debug_set_level (RIG_DEBUG_TRACE);
+
+	/* initialise debug handler */
+	grig_debug_init (NULL);
+
+	/* launch rig daemon and pass the relevant
+	   command line options
+	*/
+	if (rig_daemon_start (rignum,
+			      rigfile,
+			      rigspeed,
+			      civaddr,
+			      rigconf,
+			      delay,
+			      nothread,
+			      ptt,
+			      pstat))
+	{
 
-	/* launch rig daemon */
-	if (rig_daemon_start (rignum, rigfile, rigspeed, civaddr, rigconf, delay, nothread)) {
 		return 1;
 	}
 
@@ -327,10 +359,10 @@ main (int argc, char *argv[])
 	   debuglevel, otherwise use RIG_DEBUG_WARN.
 	*/
 	if ((debug >= RIG_DEBUG_NONE) && (debug <= RIG_DEBUG_TRACE)) {
-		rig_set_debug (debug);
+		grig_debug_set_level (debug);
 	}
 	else {
-		rig_set_debug (RIG_DEBUG_WARN);
+		grig_debug_set_level (RIG_DEBUG_WARN);
 	}
 
 	/* create application */
@@ -405,18 +437,21 @@ grig_app_create       (gint rignum)
 }
 
 
-/** \brief Handler terminate signals.
+/** \brief Handle terminate signals.
  *  \param sig The signal that has been received.
  *
  * This function is used to handle termination signals received by the program.
- * The currently caught signals are SIGTERM, SIGINT and SIGABRT. When one of these
- * signals is received, the function sends an error message to hamlib and tries
- * to make a clean exit.
+ * The currently caught signals are SIGTERM, SIGINT and SIGABRT. When one of
+ * these signals is received, the function sends an error message to hamlib and
+ * tries to make a clean exit.
  */
 static void grig_sig_handler (int sig)
 {
-	rig_debug (RIG_DEBUG_ERR, "*** GRIG: Received signal: %d\n", sig);
-	rig_debug (RIG_DEBUG_ERR, "*** GRIG: Trying clean exit...\n");
+
+	grig_debug_local (RIG_DEBUG_ERR,
+			  _("Received signal %d\n"\
+			    "Trying clean exit..."),
+			  sig);
 
 	gtk_widget_destroy (grigapp);
 }
@@ -461,7 +496,7 @@ grig_app_destroy    (GtkWidget *widget,
 {
 
 	/* set debug level to TRACE */
-	rig_set_debug (RIG_DEBUG_TRACE);
+	grig_debug_set_level (RIG_DEBUG_TRACE);
 
 	/* stop daemons */
 	rig_daemon_stop ();
@@ -470,6 +505,9 @@ grig_app_destroy    (GtkWidget *widget,
 
 	/* stop timeouts */
 
+	/* shut down debug handler */
+      	grig_debug_close ();
+
 	/* exit Gtk+ */
 	gtk_main_quit ();
 }
@@ -503,6 +541,10 @@ grig_show_help      ()
 		   "start daemon without using threads\n"));
 	g_print (_("  -l, --list                  "\
 		   "list supported radios and exit\n"));
+	g_print (_("  -p, --enable-ptt            "\
+		   "enable PTT button\n"));
+	g_print (_("  -P, --enable-pwr            "\
+		   "enable POWER button\n"));
 	g_print (_("  -h, --help                  "\
 		   "show this help message and exit\n"));
 	g_print (_("  -v, --version               "\
@@ -557,7 +599,7 @@ grig_show_version   ()
 	g_print (_("Graphical User Interface for the "\
 		   "Hamradio Control Libraries."));
 	g_print ("\n\n");
-	g_print (_("Copyright (C)  2001-2005  Alexandru Csete."));
+	g_print (_("Copyright (C)  2001-2006  Alexandru Csete."));
 	g_print ("\n");
 	g_print (_("This is free software; see the source for "\
 		   "copying conditions. "));
@@ -598,7 +640,7 @@ grig_list_rigs ()
 	array = g_array_new (FALSE, FALSE, sizeof (grig_rig_info_t));
 
 	/* make hamlib quiet and load all backends */
-	rig_set_debug (RIG_DEBUG_NONE);
+	grig_debug_set_level (RIG_DEBUG_NONE);
 	rig_load_all_backends();
 
 	/* fill list using rig_list_foreach */
