@@ -2,7 +2,7 @@
 /*
     Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2005  Alexandru Csete.
+    Copyright (C)  2001-2006  Alexandru Csete.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -23,11 +23,11 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the
-          Free Software Foundation, Inc.,
-	  59 Temple Place, Suite 330,
-	  Boston, MA  02111-1307
-	  USA
+    along with this program; if not, visit http://www.fsf.org/
+ 
+ 
+ 
+ 
 */
 #ifndef RIG_UTILS_H
 #define RIG_UTILS_H 1
@@ -39,5 +39,6 @@
 guint rig_utils_mode_to_index (gint mode);
 guint rig_utils_index_to_mode (gint index);
 
+void  rig_utils_chk_ext (gchar **filename, const gchar *ext);
 
 #endif
